/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.sanskritlibrary.validate;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.sanskritlibrary.servlet.SanskritLibraryServlet;

/**
 *
 * @author ralph
 */
public class ValidateConfiguration extends SanskritLibraryServlet {

    /**
     * Processes requests for both HTTP
     * <code>GET</code> and
     * <code>POST</code> methods.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    int subdirectoryNumber = 1;
    String datadir;

    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        String param = null;
        String status;
        File f;
        StringBuilder sb = new StringBuilder();
        sb.append("<html><head></head><body>\n");
        // dataDirectory
        String parameterName = "dataDirectory";
        boolean datadirExists = checkParameter(sb, parameterName, true, "This is required for any application that needs SL data");
        
        if (datadirExists) {
            datadir = this.getServletContext().getInitParameter(parameterName);

            sb.append(String.format("<h4>Checking subdirectories of %s</h4>\n", datadir));
            if (!datadir.endsWith("/")) {
                datadir += "/";
            }
            checkSubdirectory(sb, datadir, "texts", "Contains .slp, .roman, .deva versions of Sanskrit Library texts");
            checkSubdirectory(sb, datadir, "transcoders", "Contains transcoding files pairs: x->slp, slp-x");
            checkSubdirectory(sb, datadir, "pages", "Contains indexes used to create drop lists in TextViewer");
            checkSubdirectory(sb, datadir, "catalog", "Contains catalog HTML files created by siva.");
            checkSubdirectory(sb, datadir, "lexicons", "Contains text-specific dictionaries, e.g. Peter's Ramopakhyana and azwADyAyIHead");
            checkSubdirectory(sb, datadir, "registration", "Will contain registration information.");
            checkSubdirectory(sb, datadir, "miscellaneous", "Contains dictionaryLinks.xml used by the integrated dictionaries.");
            checkSubdirectory(sb, datadir, "uploads", "Contains converted texts from users of SL's transcoding tools.");
            checkSubdirectory(sb, datadir, "htdocs", "Contains HTML files that shouldn't be in sl.war");

            checkSubdirectory(sb, datadir, "wordlists", "Output directory for word frequency lists. <b><i>Currently not accessible from sanskritlibrary.org</i></b>");
            checkSubdirectory(sb, datadir, "textHeaders", "Used to compile lists of word frequencies. <b><i>Currently not accessible from sanskritlibrary.org</i></b>");
            checkSubdirectory(sb, datadir, "mss", "Contains cropped images. <b><i>Currently not accessible from sanskritlibrary.org</i></b>");
        }
        
        checkParameter(sb, "taggingDirectory", true, "This is used by the annotation application"); // taggingDirectory
        checkParameter(sb, "currentDomain", false, "This is used by the SL application");
        checkParameter(sb, "appName", false, "This is used by the SL application");
        checkParameter(sb, "shStatic", false, "Used to communicate with local version of Sanskrit Heritage site.");
        checkParameter(sb, "shCGI", false, "Used to communicate with Gerard's Sanskrit Heritage site.");
        checkParameter(sb, "nominalMorphology", false, "This is used by the SL application.");
        checkParameter(sb, "verbalMorphology", false, "This is used by the SL application.");
        checkParameter(sb, "fflexLocation", false, "This is used by the SL application.");
        checkParameter(sb, "apacheDirectory", true, "This is used by the SL application.");
        checkParameter(sb, "Scandir", true, "This is used by Pawan's multi-dictionary.");
        checkParameter(sb, "pDirectory", true, "This is used by ep.");
        
        sb.append("</body></html>\n");
        this.writeResult(response, sb.toString(), "text/html");        
    }
    
    
    private boolean checkParameter (StringBuilder sb, String parameterName, boolean isURL, String comment) {
        boolean rc = true;
        String parameterValue = this.getServletContext().getInitParameter(parameterName);

        if (parameterValue == null) {
            sb.append(String.format("<p><span style='color:red'>Parameter %s not found</span> in context.xml. (%s)</p>\n", 
                    parameterName, comment));            
            rc = false;
        } else {
            String status = "OK";
            if (isURL) {
                File f = new File(parameterValue);
                if (f.exists() == false) {
                    status = "<span style='color:red'>directory does not exist</span>";
                    rc = false;
                }
            }
        
            sb.append(String.format("<p>[%s] %s: %s (%s)</p>\n", parameterName, parameterValue, status, comment));
        }
        return rc;        
    }
    
    private boolean checkSubdirectory (StringBuilder sb, String datadir, String subdir, String comment) {
        boolean rc = true;
        String path = String.format("%s%s", datadir, subdir);
        File f = new File(path);
        String status = "OK";
        if (!f.exists()) {
            status = "<span style='color:red'>does not exist</span>";
            rc = false;
        }
        sb.append(String.format("<p>&nbsp;&nbsp;%d. [.../%s]: %s (%s)\n</p>", 
                subdirectoryNumber++, subdir, status, comment));
        
        return rc;
    }

    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
    }

    /**
     * Returns a short description of the servlet.
     *
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }// </editor-fold>
}
